﻿using System;
using System.Windows;
using System.Windows.Media;
using System.Windows.Media.Imaging;
using Arction.Wpf.Charting;
using Arction.Wpf.Charting.Annotations;

namespace WpfApplication1
{
    public partial class MainWindow : Window
    {
        public MainWindow()
        {
            InitializeComponent();
            CreateChart();
        }

        private void CreateChart()
        {            
            //Disable rendering, strongly recommended before updating chart properties
            m_chart.BeginUpdate();

            m_chart.ViewXY.ZoomPanOptions.AspectRatioOptions.AspectRatio = ViewAspectRatio.Manual;
            m_chart.ViewXY.ZoomPanOptions.AspectRatioOptions.ManualAspectRatioWH = 1.2;

            //Set map annotations.
            AnnotationXY worldMapAnnotation;
            Uri uri = new Uri(AppDomain.CurrentDomain.BaseDirectory + "Resources\\Map\\world.jpg");
            worldMapAnnotation = new AnnotationXY(m_chart.ViewXY, m_chart.ViewXY.XAxes[0], m_chart.ViewXY.YAxes[0]);
            worldMapAnnotation.Sizing = AnnotationXYSizing.AxisValuesBoundaries;
            worldMapAnnotation.Fill.Bitmap.Image = BitmapFrame.Create(uri);
            worldMapAnnotation.Fill.Style = RectFillStyle.Bitmap;
            worldMapAnnotation.AxisValuesBoundaries.SetValues(-180, 180, -90, 90);
            worldMapAnnotation.Fill.Bitmap.Layout = BitmapFillLayout.Stretch;
            worldMapAnnotation.Style = AnnotationStyle.Rectangle;
            worldMapAnnotation.MouseInteraction = false;
            worldMapAnnotation.Behind = true;
            worldMapAnnotation.Fill.Color = Colors.Transparent;
            worldMapAnnotation.Fill.GradientFill = GradientFill.Solid;
            worldMapAnnotation.Shadow.Visible = false;
            worldMapAnnotation.TextStyle.Visible = false;
            worldMapAnnotation.BorderLineStyle.Color = Colors.Red;
            m_chart.ViewXY.Annotations.Add(worldMapAnnotation);

            AnnotationXY balticAnnotation;
            Uri uri2 = new Uri(AppDomain.CurrentDomain.BaseDirectory + "Resources\\Map\\baltic.jpg");
            balticAnnotation = new AnnotationXY(m_chart.ViewXY, m_chart.ViewXY.XAxes[0], m_chart.ViewXY.YAxes[0]);
            balticAnnotation.Sizing = AnnotationXYSizing.AxisValuesBoundaries;
            balticAnnotation.Fill.Bitmap.Image = BitmapFrame.Create(uri2);
            balticAnnotation.Fill.Style = RectFillStyle.Bitmap;
            balticAnnotation.AxisValuesBoundaries.SetValues(20.85, 28.2, 53.9, 59.7);
            balticAnnotation.Fill.Bitmap.Layout = BitmapFillLayout.Stretch;
            balticAnnotation.Style = AnnotationStyle.Rectangle;
            balticAnnotation.MouseInteraction = false;
            balticAnnotation.Behind = true;
            balticAnnotation.Fill.Color = Colors.Transparent;
            balticAnnotation.Fill.GradientFill = GradientFill.Solid;
            balticAnnotation.Shadow.Visible = false;
            balticAnnotation.TextStyle.Visible = false;
            worldMapAnnotation.BorderLineStyle.Width = 0;
            m_chart.ViewXY.Annotations.Add(balticAnnotation);

            //Setup x-axis
            m_chart.ViewXY.XAxes[0].SetRange(-180, 180);
            m_chart.ViewXY.XAxes[0].ValueType = AxisValueType.Number;
            m_chart.ViewXY.XAxes[0].ScrollMode = XAxisScrollMode.None;
            m_chart.ViewXY.XAxes[0].MinorGrid.Visible = false;
            m_chart.ViewXY.XAxes[0].MajorGrid.Pattern = LinePattern.Solid;
            m_chart.ViewXY.XAxes[0].MajorGrid.Color = Color.FromArgb(40, 0, 0, 0);
            m_chart.ViewXY.XAxes[0].ValueType = AxisValueType.MapCoordsDegNESW;
            m_chart.ViewXY.XAxes[0].Title.Text = "Longitude";

            //Setup y-axis
            m_chart.ViewXY.YAxes[0].SetRange(-90, 90);
            m_chart.ViewXY.YAxes[0].MinorGrid.Visible = false;
            m_chart.ViewXY.YAxes[0].MajorGrid.Pattern = LinePattern.Solid;
            m_chart.ViewXY.YAxes[0].MajorGrid.Color = Color.FromArgb(40, 0, 0, 0);
            m_chart.ViewXY.YAxes[0].ValueType = AxisValueType.MapCoordsDegNESW;
            m_chart.ViewXY.YAxes[0].Title.Text = "Latitude";
            
            //Allow chart rendering
            m_chart.EndUpdate();
        }
    }
}
